@@ -1,30 +1,43 @@
 package Net::CIDR::MobileJP;
 use strict;
 use warnings;
+use 5.00800;
 use Carp;
-use YAML;
 use Net::CIDR::Lite;
 use File::ShareDir ();
-our $VERSION = '0.13';
+our $VERSION = '0.14';
+
+our $yaml_loader;
+BEGIN {
+    $yaml_loader = sub {
+        ## no critic
+        if (eval "use YAML::Syck; 1;") {
+            \&YAML::Syck::LoadFile;
+        } else {
+            require YAML;
+            \&YAML::LoadFile;
+        }
+    }->();
+};
 
 sub new {
     my ($class, $stuff) = @_;
 
-    return bless {spanner => $class->_create_spanner($stuff)}, $class;
+    return bless {spanner => $class->_create_spanner($class->_load_config($stuff))}, $class;
 }
 
 sub _create_spanner {
-    my ($class, $stuff) = @_;
+    my ($class, $conf) = @_;
 
-    my @cidrs;
-    my %cidr_for = %{$class->_load_config($stuff)};
-    my $spanner = Net::CIDR::Lite->new->spanner;
-    while (my ($carrier, $ip_ranges) = each %cidr_for) {
-        my $cidr = Net::CIDR::Lite->new;
-        for my $ip_range (@$ip_ranges) {
-            $cidr->add($ip_range);
-        }
-        $spanner->add($cidr, $carrier);
+    my $spanner = Net::CIDR::Lite::Span->new;
+    while (my ($carrier, $ip_ranges) = each %$conf) {
+        $spanner->add(do {
+            my $cidr = Net::CIDR::Lite->new;
+            for my $ip_range (@$ip_ranges) {
+                $cidr->add($ip_range);
+            }
+            $cidr;
+        }, $carrier);
     }
     return $spanner;
 }
@@ -35,13 +48,13 @@ sub _load_config {
     my $data;
     if (defined $stuff && -f $stuff && -r _) {
         # load yaml from file
-        $data = YAML::LoadFile($stuff);
+        $data = $yaml_loader->($stuff);
     } elsif ($stuff) {
         # raw data
         $data = $stuff;
     } else {
         # generated file
-        $data = YAML::LoadFile(File::ShareDir::module_file('Net::CIDR::MobileJP', 'cidr.yaml'));
+        $data = $yaml_loader->(File::ShareDir::module_file('Net::CIDR::MobileJP', 'cidr.yaml'));
     }
     return $data;
 }
